(function( $ ) {
	'use strict';

	// Create the defaults once
	var pluginName = "WooCommerceCartPDF",
		defaults = {
			'modalHeightAuto' : '1',
		};

	// The actual plugin constructor
	function Plugin ( element, options ) {
		this.element = element;
		
		this.settings = $.extend( {}, defaults, options );
		this._defaults = defaults;
		this.trans = this.settings.trans;
		this._name = pluginName;
		this.init();
	}

	// Avoid Plugin.prototype conflicts
	$.extend( Plugin.prototype, {
		init: function() {
			this.window = $(window);
			this.documentHeight = $( document ).height();
			this.windowHeight = this.window.height();
			this.product = {};
			this.elements = {};

			this.emailSendPopup();
			this.buttonPopup();
		},
		buttonPopup : function() {

			var that = this;
			if(that.settings.buttonPopup !== "1") {
				return;
			}

			var overlay = $('.woocommerce-cart-pdf-overlay');
			var popup = $('#woocommerce-cart-pdf-popup-button');

			if(overlay.length < 1) {
				return ;
			}
			
			var toggler = $('.woocommerce_cart_pdf_button');
			toggler.on('click', function(e) {

				e.preventDefault();
				overlay.fadeIn();
				popup.fadeIn();
			});

			overlay.on('click', function(e) {
				$(this).fadeOut();
				popup.fadeOut();
			});

			popup.on('click', '.woocommerce-cart-pdf-popup-close', function(e) {
				overlay.fadeOut();
				popup.fadeOut();
			});

		},
		emailSendPopup : function() {

			var that = this;
			var overlay = $('.woocommerce-cart-pdf-overlay');
			var popup = $('#woocommerce-cart-pdf-popup-email');

			if(overlay.length < 1) {
				return ;
			}

			var toggler = $('.woocommerce-cart-pdf-email-button');
			toggler.on('click', function(e) {

				e.preventDefault();
				overlay.fadeIn();
				popup.fadeIn();
			});

			overlay.on('click', function(e) {
				$(this).fadeOut();
				popup.fadeOut();
			});

			popup.on('click', '.woocommerce-cart-pdf-popup-close', function(e) {
				overlay.fadeOut();
				popup.fadeOut();
			});

			var addressCheckbox = $('.woocommerce-cart-pdf-email-address-checkbox');
			console.log(addressCheckbox);
			if(addressCheckbox.length > 0) {
				addressCheckbox.on('change', function(e) {
					var $this = $(this);
					if($this.is(':checked') == 1) {
						$('.woocommerce-cart-pdf-email-address-container').show();
					} else {
						$('.woocommerce-cart-pdf-email-address-container').hide();
					}
				})
			}

			$(document).on('submit', '.woocommerce-cart-pdf-email-form', function(e) {

				e.preventDefault();

				var $this = $(this);

				var data = new FormData(this);

				// var data = {
				// 	'action': 'woocommerce_cart_pdf_send_email',
				// 	'to' : $this.find('.woocommerce-cart-pdf-email-to').val(),
				// 	'from' : $this.find('.woocommerce-cart-pdf-email-from').val(),
				// 	'name' : $this.find('.woocommerce-cart-pdf-email-name').val(),
				// 	'phone' : $this.find('.woocommerce-cart-pdf-email-phone').val(),
				// 	'text' : $this.find('.woocommerce-cart-pdf-email-text').val(),
				// 	'comment' : $this.find('.woocommerce-cart-pdf-email-comment').val(),
				// };

				$('.woocommerce-cart-pdf-email-send').attr('disabled', 'disabled');
				jQuery.ajax({
					url: that.settings.ajax_url,
					type: 'post',
					dataType: 'JSON',
					processData: false,
					contentType: false,
					data: data,
					success : function( response ) {
						if(response.status == 0) {
							alert(response.message);
							$('.woocommerce-cart-pdf-email-send').removeAttr('disabled');
							return false;
						}

						$this.html(that.settings.sendCartEMailSuccessText);
					},
					error: function(jqXHR, textStatus, errorThrown) {
					    console.log('An Error Occured: ' + jqXHR.status + ' ' + errorThrown + '! Please contact System Administrator!');
					}
				});

			});
		},
	} );

	// Constructor wrapper
	$.fn[ pluginName ] = function( options ) {
		return this.each( function() {
			if ( !$.data( this, "plugin_" + pluginName ) ) {
				$.data( this, "plugin_" +
					pluginName, new Plugin( this, options ) );
			}
		} );
	};

	$(document).ready(function() {

		$( "body" ).WooCommerceCartPDF(woocommerce_cart_pdf_options);

	} );

})( jQuery );